% Newton method to find a root of a function f starting at x0
%
% Inputs
%  f	   function we want to find the root of
%  fp      derivative of f
%  fpp     second derivative of f
%  x0	   initial iterate
%  tol     desired tolerance or precision
%  maxit   maximum  number of iterations
%
% Outputs
%  xs      iteration history, last iterate is xs(end)
function xs = newton(f,fp,fpp,x0,tol,maxit)

 % TO BE COMPLETED
